

SemiAnalyticCoronagraph
=============================

.. currentmodule:: poppy

.. autoclass:: SemiAnalyticCoronagraph
   :show-inheritance:

   
     
   

   
   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~SemiAnalyticCoronagraph.propagate_mono

   
   

   
   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: propagate_mono

   
   